@@ -5,8 +5,10 @@ import gui
 
 def RunApp():
     app = QtWidgets.QApplication(sys.argv)
-    __location__ = os.path.realpath(os.path.join(os.getcwd()))
-    qss_file = open(__location__ + '/styling/style.qss').read()
+    abspath = os.path.abspath(__file__)
+    dname = os.path.dirname(abspath)
+    os.chdir(dname)
+    qss_file = open(dname + '/styling/style.qss').read()
     app.setStyleSheet(qss_file)
 
     MainWindow = QtWidgets.QMainWindow()
